==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Przepraszam</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Nie można załadować poprzedniej gry. Rozpoczęcie nowej gry.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 upłynęło</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 podjętych kroków</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 z %2 pozostałych celów</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukces</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Wstrzymane</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Polecenie</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Sterowanie</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opcja</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język aplikacji:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Proszę ponownie uruchomić ten program, aby zastosować zmianę języka.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nowa gra</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Polowanie i zabijanie</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Rekurencyjny Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stos</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stos 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stos 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stos 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stos 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algorytm:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Cele:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Polowanie i zabijanie</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Rekurencyjny Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stos</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stos 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stos 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stos 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stos 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Wyniki CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Czas</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Kroki</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algorytm</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gratulacje!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Twój wynik znajduje się w pierwszej dziesiątce.
Podaj swoje imię:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Gra</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Pokaż, gdzie byłeś</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Pokaż ilość podjętych kroków</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Pokaż upływający czas</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Płynny ruch</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Przesuń w górę:</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Przesuń w górę:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Przesuń w dół:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Przesuń w lewo:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Przesuń w prawo:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Przełącz flagę:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Motywy</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Wybierz plik motywu</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszamy</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Nie można utworzyć folderu danych.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Nie można skopiować pliku motywu</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Usunąć wybrany motyw?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Nie można usunąć wybranego motywu.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Widok</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowa</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Wskazówka</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Najlepsze wyniki</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Po&amp;większ</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Po&amp;mniejsz</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Język aplikacji...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferencje...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Gra labiryntu z góry na dół</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Prawo autorskie &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Wydano na licencji &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Ikony pochodzą z motywu &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Używany zgodnie z licencją &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> cutemaze_1.2.6.orig.tar.gz: cutemaze-1.2.6/translations/cutemaze_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Przepraszam</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Nie można załadować poprzedniej gry. Rozpoczęcie nowej gry.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 upłynęło</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 podjętych kroków</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 z %2 pozostałych celów</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukces</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Wstrzymane</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Polecenie</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Sterowanie</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Opcja</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język aplikacji:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Proszę ponownie uruchomić ten program, aby zastosować zmianę języka.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nowa gra</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Polowanie i zabijanie</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Rekurencyjny Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stos</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stos 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stos 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stos 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stos 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algorytm:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Cele:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Polowanie i zabijanie</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Rekurencyjny Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stos</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stos 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stos 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stos 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stos 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Wyniki CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Czas</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Kroki</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algorytm</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gratulacje!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Twój wynik znajduje się w pierwszej dziesiątce.
Podaj swoje imię:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Gra</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Pokaż, gdzie byłeś</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Pokaż ilość podjętych kroków</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Pokaż upływający czas</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Płynny ruch</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Przesuń w górę:</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Przesuń w górę:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Przesuń w dół:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Przesuń w lewo:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Przesuń w prawo:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Przełącz flagę:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Motywy</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Wybierz plik motywu</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Przepraszamy</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Nie można utworzyć folderu danych.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Nie można skopiować pliku motywu</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Usunąć wybrany motyw?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Nie można usunąć wybranego motywu.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>Pokaż podpowiedź:</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Widok</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowa</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Wskazówka</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Najlepsze wyniki</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Po&amp;większ</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Po&amp;mniejsz</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Język aplikacji...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferencje...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Gra labiryntu z góry na dół</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Prawo autorskie &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Wydano na licencji &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Ikony pochodzą z motywu &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Używany zgodnie z licencją &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
